/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Juha Ristolainen <juha.ristolainen@codemancers.fi>
 *              Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 *              Nick Leppänen Larsson <frals@frals.se>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "../common"

AnalogFaceBase {
    id: clockRoot

    property var currDate: new Date;
    property int hours: currDate.getHours()
    property int minutes: currDate.getMinutes()
    property int seconds: currDate.getUTCSeconds();    

    signal clicked(var mouse)

    function timeChanged(now) {
        hours = now.getHours()
        minutes = now.getMinutes()
        seconds = now.getUTCSeconds();        
    }        

    AnalogClockHand {
        id: hourHand

        z: parent.z
        handHeight: units.gu(12.5); handWidth: units.gu(1);
        rotation: (clockRoot.hours * 30) + (clockRoot.minutes / 2);
    }

    AnalogClockHand {
        id: minuteHand

        z: parent.z + 1
        handHeight: units.gu(14.5); handWidth: units.gu(0.5);
        rotation: clockRoot.minutes * 6;
    }

    AnalogClockHand {
        id: secondsHand

        z: parent.z - 1;
        handHeight: units.gu(17); handWidth:  units.gu(0.5)
        rotation: clockRoot.seconds * 6;
    }    

    MouseArea {
        anchors.fill: parent
        z: parent.z + 1;
        onClicked: clockRoot.clicked(mouse);
    }
}
