/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import QtQuick.XmlListModel 2.0

Page {
    id: worldPage

    visible: false;
    title: i18n.tr("Add City")

    function getTimeDifference(data) {
        var worldTime = data.split(' ')[1].split(':');
        var hoursWT = parseInt(worldTime[0]);
        var minutesWT = parseInt(worldTime[1]);
        var now = new Date();
        return ((hoursWT - now.getHours()) * 60 + (minutesWT - now.getMinutes()));
    }

    WorldClock {
        id: worldClockList;

        anchors { fill: parent; topMargin: units.gu(2) }

        // Xml model to retrieve timezone of searched city
        XmlListModel {
            id: cityDetailsModel;

            source: worldClockList.getCityTimezoneUrl(worldClockList.lat, worldClockList.lng)
            query: "/geonames/timezone"

            onStatusChanged: {
                if(status == XmlListModel.Ready && worldClockList.city != "null") {                    
                    worldModel.appendPreset(worldClockList.city, getTimeDifference(cityDetailsModel.get(0).time), worldClockList.lng, worldClockList.lat);
                    worldClockList.clearUserSearch();
                    pageStack.pop()
                }
            }

            XmlRole { name: "time"; query: "time/string()" }
        }

        onClicked: {
            lat = searchModel.get(index).lat;
            lng = searchModel.get(index).lng;
            city = searchModel.get(index).city;
            cityDetailsModel.reload()                        
        }
    }
}
