/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Juha Ristolainen <juha.ristolainen@codemancers.fi>
 *              Nick Leppänen Larsson <frals@frals.se>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import QtGraphicalEffects 1.0

// FIXME: Replace Rectangle with UbuntuShape when the new widget lands in the Ubuntu SDK.
Rectangle {
    id: clockRoot

    property alias innerCircle: innerCircle
    property real offset : units.gu(0.2)

    width: units.gu(32); height: units.gu(32)
    radius: width / 2
    antialiasing: true

    gradient: Gradient {
        GradientStop { position: 0.0;  color: "#512F48" }
        GradientStop { position: 0.25; color: "#583048" }
        GradientStop { position: 0.5;  color: "#653449" }
        GradientStop { position: 0.75; color: "#6D384A" }
        GradientStop { position: 1.0;  color: "#753B4A" }
    }

    // draws the outter shadow/highlight
    Rectangle {
        id: sourceOutter
        anchors { fill: parent; margins: -offset }
        radius: (width / 2)
        antialiasing: true
        gradient: Gradient {
            GradientStop { position: 0.0; color: "black" }
            GradientStop { position: 0.5; color: "transparent" }
            GradientStop { position: 1.0; color: "white" }
        }        
    }

    // mask for outer 3D effect
    Rectangle {
        id: maskOutter
        anchors.fill: sourceOutter
        color: "transparent"
        radius: (width / 2)
        antialiasing: true
        border { width: offset; color: "black" }        
    }

    // outter effect
    OpacityMask {
        anchors.fill: sourceOutter
        opacity: 0.65
        source: ShaderEffectSource {
            sourceItem: sourceOutter
            hideSource: true
        }
        maskSource: ShaderEffectSource {
            sourceItem: maskOutter
            hideSource: true
        }        
    }

    // FIXME: Replace this with UbuntuShape when the widget has landed in the SDK.
    Rectangle {
        id: innerCircle

        z: parent.z + 2
        height: units.gu(19); width: units.gu(19)
        radius: width / 2
        anchors.centerIn: parent
        antialiasing: true

        gradient: Gradient {
            GradientStop { position: 0.0;  color: "#7A4C68" }
            GradientStop { position: 0.25; color: "#804563" }
            GradientStop { position: 0.5;  color: "#864660" }
            GradientStop { position: 0.75; color: "#86465E" }
            GradientStop { position: 1.0;  color: "#964E66" }
        }

        // draws the inner highlight / shadow
        Rectangle {
            id: sourceInner;
            anchors { fill: parent; margins: -offset }
            radius: (width / 2)
            antialiasing: true
            gradient: Gradient {
                GradientStop { position: 0.0; color: "white" }
                GradientStop { position: 0.5; color: "transparent" }
                GradientStop { position: 1.0; color: "black" }
            }            
        }

        // mask for inner 3D effect
        Rectangle {
            id: maskInner
            color: "transparent"
            anchors.fill: sourceInner
            radius: (width / 2)
            antialiasing: true
            border { width: offset; color: "black" }            
        }

        // inner effect
        OpacityMask {
            opacity: 0.65
            anchors.fill: sourceInner
            source: ShaderEffectSource {
                sourceItem: sourceInner
                hideSource: true
            }
            maskSource: ShaderEffectSource {
                sourceItem: maskInner
                hideSource: true
            }            
        }
    }
}
