/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Alessandro Pozzi <signor.hyde@gmail.com>
 *              Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "StopwatchSupport.js" as SScript
import "../common"

// This component draws the stopwatch analog UI and defines different UI modes like normal and easteregg.
AnalogFaceBase {
    id: analogStopwatch

    property var startTime: 0;
    property var stopTime: 0;
    property int delay : 0;
    property bool flag: true;
    property int totalTime: 0;

    property int hours: 0;
    property int minutes: 0;
    property int seconds: 0;
    property int milliseconds: 0;
    property int decimalgradient: 0;  

    // Sets the location and visible (bool) values of the blip (small circle visible when the lap button is pressed)
    property alias blipLocation: blipFist.location;
    property alias blipVisible: blipFist.visible;

    // Retrieves the status of the stopwatch timer
    property bool timerStatus: stopwatchUIUpdate.running    

    function reset() {
        decimalgradient = totalTime = milliseconds = seconds = minutes = hours = 0
        SScript.deltaTime[0] = SScript.deltaTime[1] = SScript.deltaTime[2] = SScript.deltaTime[3] = 0
        startTime = stopTime = delay = 0;
        flag = true;
    }

    function start() {
        stopwatchUIUpdate.start()
    }

    function stop() {
        stopwatchUIUpdate.stop()
    }        

    // Timer which runs every 100 microseconds to update the time and also the trailing hand gradient.
    Timer {
        id: stopwatchUIUpdate

        interval: 100
        repeat: true
        onTriggered: {            
            totalTime = SScript.delta();
            SScript.deltaTime = SScript.msToTime(totalTime)
            hours = SScript.deltaTime[0];
            minutes = SScript.deltaTime[1];
            seconds = SScript.deltaTime[2];
            milliseconds = SScript.deltaTime[3];
            decimalgradient = minutes * 10;
        }
    }

    // This component draws the small orange circle that is visible everytime the lap button is pressed.
    Blip {
        id: blipFist
    }
    
    // This component draws the trailing shadow of the second hand.
    HandGradient {
        id: gradientSecond
        rotationAngle: minutes * 6
        decimalGradient: decimalgradient
    }

    Repeater {
        id:stopwatchMarkers
        
        model: ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23"]
        
        delegate: AnalogClockMarker {
            number: modelData            
            total: 24;
            size: 0.2
            distance: 0.32            
        }
    }

    AnalogClockHand {
        id: hourHand

        z: parent.z
        handHeight: units.gu(12.5); handWidth: units.gu(1);
        rotation: hours * 15;
    }

    AnalogClockHand {
        id: minuteHand

        z: parent.z
        handHeight: units.gu(14.5); handWidth: units.gu(0.5);
        rotation: minutes * 6;
    }

    AnalogClockHand {
        id: secondHand

        z: parent.z - 1;
        handHeight: units.gu(17); handWidth:  units.gu(0.5)
        rotation: seconds * 6;
    }
}
