# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; version 3.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

from ubuntuuitoolkit import emulators as toolkit_emulators


class MainView(toolkit_emulators.MainView):
    def get_stopwatch_label(self):
        """Returns the select for the stopwatch label"""
        return self.select_single("Label", objectName="labelStopwatch")

    def get_stopwatch_button(self):
        """Returns the select for the stopwatch button"""
        return self.select_single("AnalogStopwatch", objectName="buttonStopwatch")

    def get_lap_button(self):
        """Returns the select for the lap button"""
        return self.select_single("Button", objectName="lapButton")

    def get_reset_button(self):
        """Returns the select for the reset button"""
        return self.select_single("ImageButton", objectName="resetButton")

    def get_laps(self):
        """Returns the select for the lap count"""
        return self.select_single("ListModel", objectName="laps")

    def get_toolbar_timer(self):
        """Returns the toolbar of timer tab"""
        return self.select_single("ToolbarItems")

    def get_toolbar_timer_button(self, button_idx):
        """Returns a button of toolbar of timer tab"""
        toolbar = self.select_single("ToolbarItems")
        button = toolbar.get_children()
        return button[button_idx]

    def get_toolbar_timer_add_preset_button(self):
        """Returns the button for add preset of toolbar of timer tab"""
        return self.select_single('ActionItem', objectName="addPresetButton")

    def get_toolbar_timer_save_preset_button(self):
        """Returns the button for add preset of toolbar of timer tab"""
        return self.select_single("ActionItem", objectName="savePresetButton")

    def get_timer_name_preset(self):
        """Returns the TextField where insert the name of the preset"""
        return self.select_single("TextField", objectName="namePreset")

    def get_timer_minute_hand(self):
        """Returns the hour hand of clock in timer tab"""
        return self.select_single("AnalogTouchHand", objectName="minuteHand")

    def get_preset_label_text(self):
        """Returns the label with the preset text"""
        preset = self.select_many("Label", objectName="presetTextLabel")
        return preset[0] #last preset, the one created by autopilot

    def get_preset_label_timer(self):
        """Returns the label with the preset timer"""
        preset = self.select_many("Label", objectName="presetTimerLabel")
        return preset[0] #last preset, the one created by autopilot

    def get_label_timer(self):
        """Return the label with the timer countdown"""
        return self.select_single("Label", objectName="labelTimer")

    def get_num_of_presets(self):
        """Returns the number of presets in the timer page."""
        timer_page = self.select_single("TimerPage")
        return int(timer_page.select_single("QQuickListView").count)

    def get_first_preset_list_item(self):
        """Returns the first preset list item in the timer page."""
        return self.select_single("Standard", objectName="preset0")

    def get_time_label(self):
        """Return the label with the timer countdown"""
        return self.select_single("Label", objectName="currentTimeLabel")
