# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>

"""Tests for the Clock App - Stopwatch"""

from __future__ import absolute_import

from testtools.matchers import Equals, NotEquals, Is, Not
from autopilot.matchers import Eventually

from ubuntu_clock_app.tests import ClockAppTestCase

class TestStopwatch(ClockAppTestCase):
    """Tests the stopwatch page features"""

    """ This is needed to wait for the application to start.
        In the testfarm, the application may take some time to show up."""
    def setUp(self):
        super(TestStopwatch, self).setUp()
        self.assertThat(
            self.main_view.visible, Eventually(Equals(True)))

        #move to stopwatch tab
        #ignoring the emulator tab functions until fixed
        self.main_view.switch_to_tab("StopwatchTab")

    def tearDown(self):
        super(TestStopwatch, self).tearDown()

    def test_start_stop_reset_stopwatch(self):
        """Test to check the proper functioning of the start/stop/reset of stopwatch"""

        self.assertThat(self.main_view.get_stopwatch_button, Eventually(Not(Is(None))))
        start_stop_button = self.main_view.get_stopwatch_button()
        self.assertThat(self.main_view.get_stopwatch_label, Eventually(Not(Is(None))))
        stopwatch_label = self.main_view.get_stopwatch_label()
        self.assertThat(self.main_view.get_reset_button, Eventually(Not(Is(None))))
        reset_button = self.main_view.get_reset_button()

        # Press the start button to start the stopwatch
        self.assertThat(self.main_view.get_stopwatch_label, Eventually(Not(Is(None))))
        stopwatch_label_before = self.main_view.get_stopwatch_label().text
        self.pointing_device.click_object(start_stop_button)
        self.assertThat(stopwatch_label.text, Eventually(NotEquals("00:00.0")))

        # Press stop and check if the stopwatch has indeed stopped
        self.pointing_device.click_object(start_stop_button)
        self.assertThat(stopwatch_label_before, NotEquals(self.main_view.get_stopwatch_label().text))
        stopwatch_label_after = lambda: self.main_view.get_stopwatch_label().text
        self.assertThat(stopwatch_label_after, Eventually(Equals(self.main_view.get_stopwatch_label().text)))

        # Press reset and check if the stopwatch has been resetted
        self.pointing_device.click_object(reset_button)
        self.assertThat(stopwatch_label.text, Eventually(Equals("00:00.0")))
