# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Riccardo Padovani <rpadovani@ubuntu-it.org>

"""Tests for the Clock App - Timer"""

from __future__ import absolute_import

from testtools.matchers import Equals, NotEquals, Is, Not
from autopilot.matchers import Eventually
from time import sleep
from autopilot.platform import model
from ubuntu_clock_app.tests import ClockAppTestCase

class TestTimer(ClockAppTestCase):
    """Tests the timer page features"""

    """ This is needed to wait for the application to start.
        In the testfarm, the application may take some time to show up."""
    def setUp(self):
        super(TestTimer, self).setUp()
        self.assertThat(
            self.main_view.visible, Eventually(Equals(True)))

        #move to timer tab
        self.main_view.switch_to_tab("TimerTab")

    def drag_page_up_to_show_input_box(self):
        timerFunc = lambda: self.main_view.select_single("TimerPage")
        self.assertThat(timerFunc, Eventually(Not(Is(None))))
        timer_page = self.main_view.select_single("TimerPage")

        x, y, w, h = timer_page.globalRect
        tx = x + (w / 2)
        ty = y + (h / 2)

        self.pointing_device.drag(tx, ty, tx, ty - h / 3)
        self.assertThat(
            timer_page.select_single("AnimationContainer").moving,
            Eventually(Equals(False)))

    def drag_page_down_to_previous_state(self):
        timerFunc = lambda: self.main_view.select_single("TimerPage")
        self.assertThat(timerFunc, Eventually(Not(Is(None))))
        timer_page = self.main_view.select_single("TimerPage")


        x, y, w, h = timer_page.globalRect
        tx = x + (w / 2)
        ty = y + (h / 2)

        self.pointing_device.drag(tx, ty, tx, ty + h / 3)
        self.assertThat(
            timer_page.select_single("AnimationContainer").moving,
            Eventually(Equals(False)))

    def select_name_preset_label(self):
        label = self.main_view.get_timer_name_preset()
        timeout = 0
        while label.focus != True and timeout < 10:
            self.pointing_device.click_object(label)
            sleep(1)
            timeout += 1
        return label

    def test_add_preset(self):
        """Test to check if button to add a preset working"""

        # Show the toolbar
        self.main_view.open_toolbar()

        # Click the add preset button
        self.assertThat(self.main_view.get_toolbar_timer_add_preset_button, Eventually(Not(Is(None))))
        add_preset_button = self.main_view.get_toolbar_timer_add_preset_button()
        self.pointing_device.click_object(add_preset_button)

        # Write in the label
        self.drag_page_up_to_show_input_box()
        self.assertThat(self.main_view.get_timer_name_preset, Eventually(Not(Is(None))))
        label = self.select_name_preset_label()
        self.assertThat(label.focus, Eventually(Equals(True)))
        self.keyboard.type("test")
        self.assertThat(label.text, Eventually(Equals("test")))

        self.drag_page_down_to_previous_state()

        # Set minute
        self.assertThat(self.main_view.get_timer_minute_hand, Eventually(Not(Is(None))))
        minute = self.main_view.get_timer_minute_hand()

        timeout = 0        
        while label.focus == True and timeout < 10:
            TimerLabel = self.main_view.get_label_timer()
            self.pointing_device.click_object(TimerLabel)
            sleep(1)
            timeout += 1

        x, y, w, h = minute.globalRect
        tx = x + (w / 2)
        ty = y + (h / 2.5)
        self.pointing_device.drag(tx, ty - (h / 4), tx + (w / 2), ty + (h / 2))

        self.assertThat(self.main_view.get_num_of_presets, Eventually(Not(Is(None))))
        num_of_presets_old = self.main_view.get_num_of_presets()

        # Press "Save" toolbar button
        self.assertThat(self.main_view.get_toolbar_timer_save_preset_button, Eventually(Not(Is(None))))

        #make sure preset is saved, and shows up properly
        timeout = 0
        while self.main_view.get_num_of_presets() != num_of_presets_old+1 and timeout < 10:
            save_preset_button = self.main_view.get_toolbar_timer_save_preset_button()
            self.pointing_device.click_object(save_preset_button)
            sleep(1)
            timeout += 1

    def test_delete_preset(self):
        """Test if the swipe of a preset deletes it"""

        # Create a new preset
        self.test_add_preset()

        self.assertThat(self.main_view.get_num_of_presets, Eventually(Not(Is(None))))
        num_of_presets_old = self.main_view.get_num_of_presets()
        self.assertThat(self.main_view.get_first_preset_list_item, Eventually(Not(Is(None))))

        self.drag_page_up_to_show_input_box()

        # Delete the preset
        timeout = 0
        while self.main_view.get_num_of_presets() != num_of_presets_old-1 and timeout < 10:
            first_preset = self.main_view.get_first_preset_list_item()
            x, y, w, h = first_preset.globalRect
            tx = x + (w / 8)
            ty = y + (h / 2)
            self.pointing_device.drag(tx, ty, w - w / 8, ty)
            sleep(1)
            timeout += 1

        # Check has been deleted
        self.assertThat(self.main_view.get_num_of_presets,
                Eventually(Equals(num_of_presets_old-1)))        

    def test_run_preset(self):
        """Tests if a preset can runs"""

        # Create a new preset
        self.test_add_preset()

        # Click to select the preset
        self.assertThat(self.main_view.get_first_preset_list_item, Eventually(Not(Is(None))))
        first_preset = self.main_view.get_first_preset_list_item()

        self.drag_page_up_to_show_input_box()
        self.pointing_device.click_object(first_preset)

        self.drag_page_down_to_previous_state()

        # Click to start the preset
        self.assertThat(self.main_view.get_label_timer, Eventually(Not(Is(None))))
        timeout = 0
        while self.main_view.get_label_timer() == None and timeout < 10:
            label = self.main_view.get_label_timer()
            self.pointing_device.click_object(label)
            sleep(1)
            timeout += 1

        # Check if timer is started
        self.assertThat(self.main_view.get_label_timer, Eventually(Not(Is(None))))
        label_timer = self.main_view.get_label_timer()
        self.pointing_device.click_object(label_timer)
        self.assertThat(label_timer.text, Eventually(NotEquals("21:00")))
