/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "../common"

// Component which draws the analog timer face.
AnalogFaceBase {
    id: clockOuterCircle

    property var startTime: 0;
    property var remTime: 0;

    // Properties to store/set the time variables
    property int seconds: 0;
    property int minutes: 0;    
    property int totalTime: 0;
    property int pauseTime: 0;

    // Property to activate/deactivate the timer
    property bool timerOn: false;
    property bool inProgressFlag

    // Timer function called by the main clock loop
    function onTimerUpdate () {
        if( timerOn ) {
            inProgressFlag = true;
            remTime = totalTime - Math.floor((new Date() - startTime)/ 1000) - pauseTime;

            if (remTime < 0) {
                timerOn = false
                totalTime = -1;
            } else {
                ssToTime(remTime);
            }
        }
    }

    // Function to convert time (in seconds) to hh:mm:ss format
    function ssToTime(time) {
        seconds = time % 60
        time = Math.floor(time / 60)
        minutes = time % 60        
        secondHand.rotationValue = seconds * 6;
        minuteHand.rotationValue = minutes * 6;        
    }

    // Function to disable timer and reset time
    Timer {
        id: reset_timer

        interval: 200
        repeat: false
        onTriggered: {
            inProgressFlag = true;
            minuteHand.rotationValue = secondHand.rotationValue = 0;
            inProgressFlag = false;
        }
    }

    function reset() {
        reset_timer.start();
        timerOn = false;
        state = "";
        startTime = remTime = pauseTime = 0;
        minutes = seconds = totalTime = 0;
        minuteHand.timerValue = secondHand.timerValue = 0;
    }

    Repeater {
        model: 12
        delegate: AnalogClockMarker {
            number: index
            size: 0.5
            distance: 0.48            
        }
    }

    // Minute hand with touch/mouse drag support
    AnalogTouchHand {
        id: minuteHand
        objectName: "minuteHand"

        onTimerValueChanged: minutes = timerValue;

        handHeight: units.gu(14.5); handWidth: units.gu(0.5);
        animateFlag: inProgressFlag;
        enabled: !inProgressFlag;
        grabMargin: units.gu(0)
        grabHeight: units.gu(7)
    }

    // Second hand with touch/mouse drag support
    AnalogTouchHand {
        id: secondHand

        onTimerValueChanged: seconds = timerValue;

        handHeight: units.gu(17); handWidth: units.gu(0.5);
        z: parent.z - 1;
        animateFlag: inProgressFlag;
        enabled: !inProgressFlag;
        grabMargin: -units.gu(2)
    }
}
